@@ -22,9 +22,8 @@
 #ifndef SPONGE_H_
 #define SPONGE_H_
 
-// #include <stdint.h>
-typedef unsigned int            uint32_t;
-typedef unsigned long int  uint64_t;
+typedef unsigned int uint32_t;
+typedef unsigned long int uint64_t;
 
 #if defined(__GNUC__)
 #define ALIGN __attribute__ ((aligned(32)))
@@ -45,7 +44,7 @@ static const uint64_t blake2b_IV[8] =
 };
 
 /*Blake2b's rotation*/
-static inline uint64_t rotr64( const uint64_t w, const unsigned c ){
+static __inline uint64_t rotr64( const uint64_t w, const unsigned c ){
     return ( w >> c ) | ( w << ( 64 - c ) );
 }
 
